CLI Reference - AstraGeek 0.2.0 documentation

Skip to content
Back to top
View this page

# CLI Reference

## astrageek

AstraGeek — star sky map generator.

Usage

    astrageek [OPTIONS] COMMAND [ARGS]...

Options

--version

  Show the version and exit.

### messier

Messier Object Guessing Game.

A game where players view a pinhole projection of a Messier object and try to guess its Messier number.

Usage

    astrageek messier [OPTIONS]

### pinhole

Plot pinhole projection of the skymap.

Usage

    astrageek pinhole [OPTIONS]

Options

-t, --dtime <dtime>

  Date and time. Formats examples: ‘2025-01-15 22:30’, ‘2025-01-15’, ‘15.01.2025 22:30’.

-c, --constellation <constellation>

  Constellation 3-letter code (e.g. ORI, UMA, CAS). Sets center direction.

--random-direction

  Sets random sky direction as center. Mutually exclusive with –constellation.

--tilt-angle <tilt_angle>

  Camera tilt angle in degrees.

--fov <fov>

  Field of view in degrees.

--aspect-ratio <aspect_ratio>

  Aspect ratio of the frame (default 1.5).

--height-pix <height_pix>

  Image height in pixels.

--mode <mode>

  Mode presets for teacher and student. The student setting contains all flags in the off state, resulting in a blank map with no symbols or notes. The teacher setting contains all symbols and answers

  Options:

    teacher | student

--add-ecliptic, --no-ecliptic

  Adds the great circle of the ecliptic to the map

--add-equator, --no-equator

  Adds the great circle of the celestial equator to the map.

--add-galactic-equator, --no-galactic-equator

  Adds the great circle of the galactic equator to the map.

--add-planets, --no-planets

  Marks planet’s positions.

--add-equatorial-grid, --no-equatorial-grid

  Adds an equatorial coordinate grid to the map with a specified step on each axis (see the –grid-steps option)

--grid-steps <grid_steps>

  Grid steps in degrees (requires grids).

--add-constellations, --no-constellations

  Adds constellations lines to the map.

--add-constellations-names, --no-constellations-names

  Add constellation labels (three-letter latin abbreviations.

--mag-limit <mag_limit>

  Sets map magnitude top limit (default 5.5).

--output <output>

  Sets output filename.

### stereographic

Plot stereographic projection of the skymap.

Usage

    astrageek stereographic [OPTIONS]

Options

-lat, --latitude <latitude>

  Observer’s latitude in degrees (default 0.0).

-lon, --longitude <longitude>

  Observer’s longitude in degrees (default 0.0).

-t, --dtime <dtime>

  Date and time. Formats examples: ‘2025-01-15 22:30’, ‘2025-01-15’, ‘15.01.2025 22:30’.

--mode <mode>

  Mode presets for teacher and student. The student setting contains all flags in the off state, resulting in a blank map with no symbols or notes. The teacher setting contains all symbols and answers

  Options:

    teacher | student

--add-ticks, --no-ticks

  Adds ticks: cardinal directions and azimuth marks.

--random-origin, --no-random-origin

  Randomizes map orientation.

--add-ecliptic, --no-ecliptic

  Adds the great circle of the ecliptic to the map

--add-equator, --no-equator

  Adds the great circle of the celestial equator to the map.

--add_galactic_equator, --no_galactic_equator

  Adds the great circle of the galactic equator to the map.

--add-planets, --no-planets

  Marks planet’s positions.

--add-horizontal-grid, --no-horizontal-grid

  Adds an azimuthal coordinate grid to the map with a specified step on each axis (see the –grid-steps option below)

--add-equatorial-grid, --no-equatorial-grid

  Adds an equatorial coordinate grid to the map with a specified step on each axis (see the –grid-steps option)

--grid-steps <grid_steps>

  Grid steps in degrees (requires grids).

--add-zenith, --no-zenith

  Adds the zenith label to the map.

--add-poles, --no-poles

  Adds the visible celestial pole label to the map.

--add-constellations, --no-constellations

  Adds constellations lines to the map.

--add-constellations-names, --no-constellations-names

  Add constellation labels (three-letter latin abbreviations.

--mag-limit <mag_limit>

  Sets map magnitude top limit (default 5.5).

--output <output>

  Sets output filename.